# FHIR-r4 test converter

CLI-tool for converting fhirpath [XML test cases](https://github.com/HL7/FHIRPath/tree/master/tests/r4/)
into fhirpath.js yaml test cases format with json resource files.

### Installing:
```npm ci```

### Download and convert test file and resource files:
```converter/bin/index.js```

### Converter test in whole test scope:
```npm run test```
